@@ -32,6 +32,13 @@ class _DummyInflectEngine(object):
         return noun
 
 
+# In SQLAlchemy 0.x, constraint.columns is sometimes a list, on 1.x onwards, always a ColumnCollection
+def _get_column_names(constraint):
+    if isinstance(constraint.columns, list):
+        return constraint.columns
+    return list(constraint.columns.keys())
+
+
 def _convert_to_valid_identifier(name):
     assert name, 'Identifier cannot be empty'
     if name[0].isdigit() or iskeyword(name):
@@ -62,7 +69,7 @@ def _get_compiled_expression(statement):
 def _get_constraint_sort_key(constraint):
     if isinstance(constraint, CheckConstraint):
         return 'C{0}'.format(constraint.sqltext)
-    return constraint.__class__.__name__[0] + repr(constraint.columns)
+    return constraint.__class__.__name__[0] + repr(_get_column_names(constraint))
 
 
 def _get_common_fk_constraints(table1, table2):
@@ -172,7 +179,7 @@ def _render_constraint(constraint):
         remote_column = '{0}.{1}'.format(constraint.column.table.fullname, constraint.column.name)
         return 'ForeignKey({0})'.format(render_fk_options(remote_column))
     elif isinstance(constraint, ForeignKeyConstraint):
-        local_columns = constraint.columns
+        local_columns = _get_column_names(constraint)
         remote_columns = ['{0}.{1}'.format(fk.column.table.fullname, fk.column.name)
                           for fk in constraint.elements]
         return 'ForeignKeyConstraint({0})'.format(render_fk_options(local_columns, remote_columns))
@@ -294,7 +301,8 @@ class ModelClass(Model):
         for constraint in sorted(table.constraints, key=_get_constraint_sort_key):
             if isinstance(constraint, ForeignKeyConstraint):
                 target_cls = self._tablename_to_classname(constraint.elements[0].column.table.name, inflect_engine)
-                if detect_joined and self.parent_name == 'Base' and set(constraint.columns) == pk_column_names:
+                if (detect_joined and self.parent_name == 'Base' and
+                        set(_get_column_names(constraint)) == pk_column_names):
                     self.parent_name = target_cls
                 else:
                     relationship_ = ManyToOneRelationship(self.name, target_cls, constraint, inflect_engine)
@@ -409,7 +417,8 @@ class ManyToOneRelationship(Relationship):
     def __init__(self, source_cls, target_cls, constraint, inflect_engine):
         super(ManyToOneRelationship, self).__init__(source_cls, target_cls)
 
-        colname = constraint.columns[0]
+        column_names = _get_column_names(constraint)
+        colname = column_names[0]
         tablename = constraint.elements[0].column.table.name
         if not colname.endswith('_id'):
             self.preferred_name = inflect_engine.singular_noun(tablename) or tablename
@@ -418,7 +427,7 @@ class ManyToOneRelationship(Relationship):
 
         # Add uselist=False to One-to-One relationships
         if any(isinstance(c, (PrimaryKeyConstraint, UniqueConstraint)) and
-               set(col.name for col in c.columns) == set(constraint.columns)
+               set(col.name for col in c.columns) == set(column_names)
                for c in constraint.table.constraints):
             self.kwargs['uselist'] = 'False'
 
@@ -432,7 +441,7 @@ class ManyToOneRelationship(Relationship):
         # SQLAlchemy needs an explicit primaryjoin to figure out which column(s) to join with
         common_fk_constraints = _get_common_fk_constraints(constraint.table, constraint.elements[0].column.table)
         if len(common_fk_constraints) > 1:
-            self.kwargs['primaryjoin'] = "'{0}.{1} == {2}.{3}'".format(source_cls, constraint.columns[0], target_cls,
+            self.kwargs['primaryjoin'] = "'{0}.{1} == {2}.{3}'".format(source_cls, column_names[0], target_cls,
                                                                        constraint.elements[0].column.name)
 
 
@@ -443,15 +452,15 @@ class ManyToManyRelationship(Relationship):
         self.kwargs['secondary'] = repr(assocation_table.name)
         constraints = [c for c in assocation_table.constraints if isinstance(c, ForeignKeyConstraint)]
         constraints.sort(key=_get_constraint_sort_key)
-        colname = constraints[1].columns[0]
+        colname = _get_column_names(constraints[1])[0]
         tablename = constraints[1].elements[0].column.table.name
         self.preferred_name = tablename if not colname.endswith('_id') else colname[:-3] + 's'
 
         # Handle self referential relationships
         if source_cls == target_cls:
             self.preferred_name = 'parents' if not colname.endswith('_id') else colname[:-3] + 's'
-            pri_pairs = zip(constraints[0].columns, constraints[0].elements)
-            sec_pairs = zip(constraints[1].columns, constraints[1].elements)
+            pri_pairs = zip(_get_column_names(constraints[0]), constraints[0].elements)
+            sec_pairs = zip(_get_column_names(constraints[1]), constraints[1].elements)
             pri_joins = ['{0}.{1} == {2}.c.{3}'.format(source_cls, elem.column.name, assocation_table.name, col)
                          for col, elem in pri_pairs]
             sec_joins = ['{0}.{1} == {2}.c.{3}'.format(target_cls, elem.column.name, assocation_table.name, col)
@@ -466,7 +475,8 @@ class CodeGenerator(object):
     header = '# coding: utf-8'
     footer = ''
 
-    def __init__(self, metadata, noindexes=False, noconstraints=False, nojoined=False, noinflect=False):
+    def __init__(self, metadata, noindexes=False, noconstraints=False, nojoined=False, noinflect=False,
+                 noclasses=False):
         super(CodeGenerator, self).__init__()
 
         if noinflect:
@@ -530,7 +540,7 @@ class CodeGenerator(object):
                                 continue
 
             # Only form model classes for tables that have a primary key and are not association tables
-            if not table.primary_key or table.name in association_tables:
+            if noclasses or not table.primary_key or table.name in association_tables:
                 model = ModelTable(table)
             else:
                 model = ModelClass(table, links[table.name], inflect_engine, not nojoined)
