@@ -21,7 +21,8 @@ if sys.version_info < (3,):
     def remove_unicode_prefixes(text):
         return unicode_re.sub(r"\1\2\1", text)
 else:
-    remove_unicode_prefixes = lambda text: text
+    def remove_unicode_prefixes(text):
+        return text
 
 
 class TestModelGenerator(object):
@@ -800,6 +801,26 @@ class SimpleItems(Base):
     id = Column(Integer, primary_key=True)
 """
 
+    def test_no_classes(self):
+        Table(
+            'simple_items', self.metadata,
+            Column('id', INTEGER, primary_key=True)
+        )
+
+        assert self.generate_code(noclasses=True) == """\
+# coding: utf-8
+from sqlalchemy import Column, Integer, MetaData, Table
+
+
+metadata = MetaData()
+
+
+t_simple_items = Table(
+    'simple_items', metadata,
+    Column('id', Integer, primary_key=True)
+)
+"""
+
     def test_table_kwargs(self):
         Table(
             'simple_items', self.metadata,
